godev

package
v1.4.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 23, 2026 License: MIT Imports: 18 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func NewCmd

func NewCmd() *cobra.Command

NewCmd returns the go-dev subcommand group.

Types

type Scrape

type Scrape struct {
	Date    string
	Version string
	Targets []Target
}

Scrape contains the scraped output from the Go Download website, ready for serialisation into a Nix attribute set.

func (*Scrape) Filename

func (s *Scrape) Filename() string

func (*Scrape) String

func (s *Scrape) String() string

type Target

type Target struct {
	SHA256 string
	URL    string
	System string
}

Target contains the core details for Nix to download a copy of Go for any supported OS-Arch combination

Jump to